@@ -25,6 +25,6 @@ function(latitude, longitude){
     N = N0 + m0*((M - M0) + niu_s*(sin(phi))*((lambda - lambda0)^2/2)*(cos(phi)))
     #### Eq. 2
     E = E0 + m0*(niu_s*(lambda - lambda0)*cos(phi) + niu_s*((lambda - lambda0)^3/6)*(cos(phi)^3)*(psi_s - tan(phi)^2))
-    res <- list(N = N, E = E)
+    res <- data.frame(N = N, E = E)
     return(res)
 }
