@@ -3,5 +3,6 @@ function(latitude, longitude){
     #### The latitude and longitude should be both in decimal format. 
     lat <- latitude - 5.5/3600
     long <- longitude + 8.8/3600
-    return(list(latitude = lat, longitude = long))
+    res <- data.frame(latitude = lat, longitude = long)
+    return(res)
 }
